#d;
clear;
set more off;
********************************************************************************
*     PROGRAM NAME:   STATA SAMPLE CODE FOR COMPUTING A CALENDAR YEAR ESTIMATE *
*					  FOR A STATE USING THE STATE WEIGHTS (New York)           *
*                                                                              *
*     WRITTEN BY:             Taylor J. Wilson - 9 May 2019		               *
*     VERSION :               SE/15  (FOR STATA VERSION 11 OR HIGHER)          *
*                                                                              *
*     The results of this program are intended to outline the procedures       *
*     for computing PUMD weighted estimates. Any errors are mine alone.        *
*                                                                              *
********************************************************************************
********************************************************************************
/*Set directory*/
#d ;
global inPath   = "PATHWAY"; 
********************************************************************************
/*These are the datasets we will need for 2017 data.*/
#d ;
use "$inPath\fmli171x.dta" ; 
append using "$inPath\fmli172.dta" ;
append using "$inPath\fmli173.dta" ;
append using "$inPath\fmli174.dta" ;  
append using "$inPath\fmli181.dta" ;

/*Merge in the state weight file. All New York Consumer Units will match to 
the FMLI files.*/
merge 1:1 newid using "$inPath\nywgt17";
keep if _merge == 3;
drop _merge;

/*The following steps create three groups for quarters. Since quarter 2, 3, and 
  4 are treated the same, we call them all quarter '3.' Quarter 1 and quarter 5
  have special rules for determining which observations are classified.*/
  
gen quarter = 3 ;

replace quarter = 1 if (qintrvmo == "01" | qintrvmo == "02" | qintrvmo == "03")
& qintrvyr == "2017" ;
replace quarter = 5 if (qintrvmo == "01" | qintrvmo == "02" | qintrvmo == "03")
& qintrvyr == "2018" ;

/*Next we need weighted expenditure variable for each quarter. Since we are 
  interested in calendar year only, we only need the cq_var for the first 
  quarter and the pq_var for the fifth quarter. All other quarters require the
  sum of these two variables because both the previous quarter and the current
  quarter are contained within the calendar year.*/

#d ; 
gen cal_totexp = totexpcq*nywgt if quarter==1 ;
	replace cal_totexp = totexppq*nywgt if quarter==5 ;
	replace cal_totexp = ((totexpcq + totexppq)*nywgt) if quarter==3 ;
  
#d ; 
gen cal_totexp1 = foodcq*nywgt if quarter==1 ;
	replace cal_totexp1 = foodpq*nywgt if quarter==5 ;
	replace cal_totexp1 = ((foodcq + foodpq)*nywgt) if quarter==3 ;
	
#d ; 
gen cal_totexp2 = transcq*nywgt if quarter==1 ;
	replace cal_totexp2 = transpq*nywgt if quarter==5 ;
	replace cal_totexp2 = ((transcq + transpq)*nywgt) if quarter==3 ;
	
#d ; 
gen cal_totexp3 = houscq*nywgt if quarter==1 ;
	replace cal_totexp3 = houspq*nywgt if quarter==5 ;
	replace cal_totexp3 = ((houscq + houspq)*nywgt) if quarter==3 ;
	
#d ; 
gen cal_totexp4 = healthcq*nywgt if quarter==1 ;
	replace cal_totexp4 = healthpq*nywgt if quarter==5 ;
	replace cal_totexp4 = ((healthcq + healthpq)*nywgt) if quarter==3 ;
	
#d ; 
gen cal_totexp5 = entertcq*nywgt if quarter==1 ;
	replace cal_totexp5 = entertpq*nywgt if quarter==5 ;
	replace cal_totexp5 = ((entertcq + entertpq)*nywgt) if quarter==3 ;
	
/*Next the weights need to be adjusted for the calendar year estimates to 
  reflect the number of months of the reference period that the CU could report
  expenditures that occured in the calendar year.
  
  This changed the month variable from character to numeric.*/

#d ;
gen month = real(qintrvmo) ;

/*This is called the "months in scope" adjustment. We are scaling the weight 
  applied to the expenditure by a factor depending on how many months in the 
  year of interest are in the scope of our calendar year. We divide everything 
  by four to account for the fact that the weight is designed to sum to the 
  national population in each quarter dataset. Since we are constructing a year
  of data, we need to scale the weight by the number of quarters in a year, or
  by four.*/

#d ;
gen cal_popweight = nywgt*(((month-1)/3)/4) if quarter == 1 ;
	replace cal_popweight = nywgt*(((4-month)/3)/4) if quarter == 5 ;
	replace cal_popweight = nywgt/4 if quarter == 3 ;

/*Now we need to generate aggregate expenditure and population weight 
  variables by summing up all the observations for the variables of interest. 
  The count variable is added just to store the total number of CUs were in the
  original sample. Some researchers like to keep this information on hand.*/

#d ;
gen count = 1 ;

#d ;
collapse (sum) 
agg_cal_wt = cal_popweight 
agg_cal_totexp = cal_totexp
agg_cal_totexp1 = cal_totexp1
agg_cal_totexp2 = cal_totexp2
agg_cal_totexp3 = cal_totexp3
agg_cal_totexp4 = cal_totexp4
agg_cal_totexp5 = cal_totexp5
count;

/*Lastly, generate calendar year means using the aggregate population weight and
  the aggregate weighted expenditure then review the results.*/ 

#d ; 
gen mean_cal_totexp = agg_cal_totexp / agg_cal_wt ;
gen mean_cal_totexp1 = agg_cal_totexp1 / agg_cal_wt ;
gen mean_cal_totexp2 = agg_cal_totexp2 / agg_cal_wt ;
gen mean_cal_totexp3 = agg_cal_totexp3 / agg_cal_wt ;
gen mean_cal_totexp4 = agg_cal_totexp4 / agg_cal_wt ;
gen mean_cal_totexp5 = agg_cal_totexp5 / agg_cal_wt ;

rename mean_cal_totexp  Expenditures;
rename mean_cal_totexp1 Food;
rename mean_cal_totexp2 Transportation;
rename mean_cal_totexp3 Housing;
rename mean_cal_totexp4 Healthcare;
rename mean_cal_totexp5 Entertainment;

keep Expenditures Food Transportation Housing Healthcare Entertainment;

xpose, clear varname;
rename v1 Value;
rename _varname Expenditure; 
